@@ -38,11 +38,10 @@
 
 #include <dialogs/ownertrustdialog.h>
 
-#include <utils/formatting.h>
+#include <Libkleo/Formatting>
 
-#include <Libkleo/CryptoBackendFactory>
-#include <Libkleo/CryptoBackend>
-#include <Libkleo/ChangeOwnerTrustJob>
+#include <QGpgME/Protocol>
+#include <QGpgME/ChangeOwnerTrustJob>
 
 #include <gpgme++/key.h>
 
@@ -55,6 +54,7 @@ using namespace Kleo;
 using namespace Kleo::Commands;
 using namespace Kleo::Dialogs;
 using namespace GpgME;
+using namespace QGpgME;
 
 class ChangeOwnerTrustCommand::Private : public Command::Private
 {
@@ -224,7 +224,7 @@ void ChangeOwnerTrustCommand::Private::createJob()
 {
     assert(!job);
 
-    const CryptoBackend::Protocol *const backend = CryptoBackendFactory::instance()->protocol(key().protocol());
+    const auto backend = (key().protocol() == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     if (!backend) {
         return;
     }
