@@ -40,14 +40,13 @@
 
 #include <dialogs/lookupcertificatesdialog.h>
 
-#include <utils/formatting.h>
-
+#include <Libkleo/Formatting>
 #include <Libkleo/Stl_Util>
-#include <Libkleo/ImportFromKeyserverJob>
-#include <Libkleo/KeyListJob>
-#include <Libkleo/CryptoBackendFactory>
-#include <Libkleo/CryptoBackend>
-#include <Libkleo/CryptoConfig>
+
+#include <QGpgME/CryptoConfig>
+#include <QGpgME/Protocol>
+#include <QGpgME/KeyListJob>
+#include <QGpgME/ImportFromKeyserverJob>
 
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
@@ -59,9 +58,6 @@
 
 #include <QRegExp>
 
-#include <boost/bind.hpp>
-#include <boost/shared_ptr.hpp>
-
 #include <vector>
 #include <map>
 #include <algorithm>
@@ -71,7 +67,7 @@ using namespace Kleo;
 using namespace Kleo::Commands;
 using namespace Kleo::Dialogs;
 using namespace GpgME;
-using namespace boost;
+using namespace QGpgME;
 
 class LookupCertificatesCommand::Private : public ImportCertificatesCommand::Private
 {
@@ -110,12 +106,12 @@ private:
     void createDialog();
     KeyListJob *createKeyListJob(GpgME::Protocol proto) const
     {
-        const CryptoBackend::Protocol *const cbp = CryptoBackendFactory::instance()->protocol(proto);
+        const auto cbp = (proto == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
         return cbp ? cbp->keyListJob(true) : 0;
     }
     ImportFromKeyserverJob *createImportJob(GpgME::Protocol proto) const
     {
-        const CryptoBackend::Protocol *const cbp = CryptoBackendFactory::instance()->protocol(proto);
+        const auto cbp = (proto == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
         return cbp ? cbp->importFromKeyserverJob() : 0;
     }
     void startKeyListJob(GpgME::Protocol proto, const QString &str);
@@ -320,7 +316,7 @@ void LookupCertificatesCommand::Private::slotImportRequested(const std::vector<K
     dialog = 0;
 
     assert(!keys.empty());
-    assert(kdtools::none_of(keys, mem_fn(&Key::isNull)));
+    assert(std::none_of(keys.cbegin(), keys.cend(), [](const Key &key) { return key.isNull(); }));
 
     std::vector<Key> pgp, cms;
     pgp.reserve(keys.size());
@@ -328,7 +324,9 @@ void LookupCertificatesCommand::Private::slotImportRequested(const std::vector<K
     kdtools::separate_if(keys.begin(), keys.end(),
                          std::back_inserter(pgp),
                          std::back_inserter(cms),
-                         boost::bind(&Key::protocol, _1) == OpenPGP);
+                         [](const Key &key) {
+                             return key.protocol() == GpgME::OpenPGP;
+                         });
 
     setWaitForMoreJobs(true);
     if (!pgp.empty())
@@ -395,21 +393,21 @@ void LookupCertificatesCommand::Private::showResult(QWidget *parent, const KeyLi
 
 static bool haveOpenPGPKeyserverConfigured()
 {
-    const Kleo::CryptoConfig *const config = Kleo::CryptoBackendFactory::instance()->config();
+    const QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
     if (!config) {
         return false;
     }
-    const Kleo::CryptoConfigEntry *const entry = config->entry(QStringLiteral("gpg"), QStringLiteral("Keyserver"), QStringLiteral("keyserver"));
+    const QGpgME::CryptoConfigEntry *const entry = config->entry(QStringLiteral("gpg"), QStringLiteral("Keyserver"), QStringLiteral("keyserver"));
     return entry && !entry->stringValue().isEmpty();
 }
 
 static bool haveX509DirectoryServerConfigured()
 {
-    const Kleo::CryptoConfig *const config = Kleo::CryptoBackendFactory::instance()->config();
+    const QGpgME::CryptoConfig *const config = QGpgME::cryptoConfig();
     if (!config) {
         return false;
     }
-    const Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), QStringLiteral("LDAP"), QStringLiteral("LDAP Server"));
+    const QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), QStringLiteral("LDAP"), QStringLiteral("LDAP Server"));
     bool entriesExist = entry && !entry->urlValueList().empty();
     entry = config->entry(QStringLiteral("gpgsm"), QStringLiteral("Configuration"), QStringLiteral("keyserver"));
     entriesExist |= entry && !entry->urlValueList().empty();
