@@ -32,11 +32,12 @@
 
 #include <config-kleopatra.h>
 
+#include "kleopatra_debug.h"
+
 #include "taskcollection.h"
 
-#include <crypto/task.h>
-
-#include <boost/bind.hpp>
+#include "crypto/task.h"
+#include "utils/gnupg-helper.h"
 
 #include <algorithm>
 #include <map>
@@ -46,7 +47,6 @@
 
 using namespace Kleo;
 using namespace Kleo::Crypto;
-using namespace boost;
 
 class TaskCollection::Private
 {
@@ -55,20 +55,20 @@ public:
     explicit Private(TaskCollection *qq);
 
     void taskProgress(const QString &, int, int);
-    void taskResult(const shared_ptr<const Task::Result> &);
+    void taskResult(const std::shared_ptr<const Task::Result> &);
     void taskStarted();
     void calculateAndEmitProgress();
 
-    std::map<int, shared_ptr<Task> > m_tasks;
-    mutable int m_totalSize;
-    mutable int m_processedSize;
+    std::map<int, std::shared_ptr<Task> > m_tasks;
+    mutable quint64 m_totalProgress;
+    mutable quint64 m_progress;
     unsigned int m_nCompleted;
     QString m_lastProgressMessage;
     bool m_errorOccurred;
     bool m_doneEmitted;
 };
 
-TaskCollection::Private::Private(TaskCollection *qq) : q(qq), m_totalSize(0), m_processedSize(0), m_nCompleted(0), m_errorOccurred(false), m_doneEmitted(false)
+TaskCollection::Private::Private(TaskCollection *qq) : q(qq), m_totalProgress(0), m_progress(0), m_nCompleted(0), m_errorOccurred(false), m_doneEmitted(false)
 {
 }
 
@@ -94,7 +94,7 @@ void TaskCollection::Private::taskProgress(const QString &msg, int, int)
     calculateAndEmitProgress();
 }
 
-void TaskCollection::Private::taskResult(const shared_ptr<const Task::Result> &result)
+void TaskCollection::Private::taskResult(const std::shared_ptr<const Task::Result> &result)
 {
     assert(result);
     ++m_nCompleted;
@@ -119,36 +119,53 @@ void TaskCollection::Private::taskStarted()
 
 void TaskCollection::Private::calculateAndEmitProgress()
 {
-    typedef std::map<int, shared_ptr<Task> >::const_iterator ConstIterator;
+    typedef std::map<int, std::shared_ptr<Task> >::const_iterator ConstIterator;
 
-    int total = 0;
-    int processed = 0;
-    uint knownSize = m_tasks.size();
+    quint64 total = 0;
+    quint64 processed = 0;
 
-    for (ConstIterator it = m_tasks.begin(), end = m_tasks.end(); it != end; ++it) {
-        const shared_ptr<Task> &i = it->second;
-        assert(i);
-        if (i->totalSize() == 0) {
-            --knownSize;
+    static bool haveWorkingProgress = engineIsVersion(2, 1, 15);
+    if (!haveWorkingProgress) {
+        // GnuPG before 2.1.15 would overflow on progress values > max int.
+        // and did not emit a total for our Qt data types.
+        // As we can't know if it overflowed or what the total is we just knight
+        // rider in that case
+        if (m_doneEmitted) {
+            Q_EMIT q->progress(m_lastProgressMessage, 1, 1);
+        } else {
+            Q_EMIT q->progress(m_lastProgressMessage, 0, 0);
         }
-        processed += i->processedSize();
-        total += i->totalSize();
-    }
-    // use the average of the known sizes to estimate the unknown ones:
-    if (knownSize > 0) {
-        total += static_cast<int>(std::ceil((m_tasks.size() - knownSize) * (static_cast<double>(total) / knownSize)));
-    }
-    if (m_totalSize == total && m_processedSize == processed) {
         return;
     }
-    m_totalSize = total;
-    m_processedSize = processed;
-    if (processed) {
-        Q_EMIT q->progress(m_lastProgressMessage, processed, total);
-    } else
-        // use knight-rider mode until we have some progress
-    {
-        Q_EMIT q->progress(m_lastProgressMessage, processed, 0);
+
+    bool unknowable = false;
+    for (ConstIterator it = m_tasks.begin(), end = m_tasks.end(); it != end; ++it) {
+        // Sum up progress and totals
+        const std::shared_ptr<Task> &i = it->second;
+        assert(i);
+        if (!i->totalProgress()) {
+            // There still might be jobs for which we don't know the progress.
+            qCDebug(KLEOPATRA_LOG) << "Task: " << i->label() << " has no total progress set. ";
+            unknowable = true;
+            break;
+        }
+        processed += i->currentProgress();
+        total += i->totalProgress();
+    }
+
+    m_totalProgress = total;
+    m_progress = processed;
+    if (!unknowable && processed && total >= processed) {
+        // Scale down to a promille value to avoid range issues.
+        int scaled = 1000 * (m_progress / static_cast<double>(m_totalProgress));
+        qCDebug(KLEOPATRA_LOG) << "Collection Progress: " << scaled << " total: " << 1000;
+        Q_EMIT q->progress(m_lastProgressMessage, scaled, 1000);
+    } else {
+        if (total < processed) {
+            qCDebug(KLEOPATRA_LOG) << "Total progress is smaller then current progress.";
+        }
+        // Knight rider.
+        Q_EMIT q->progress(m_lastProgressMessage, 0, 0);
     }
 }
 
@@ -170,16 +187,16 @@ bool TaskCollection::errorOccurred() const
     return d->m_errorOccurred;
 }
 
-shared_ptr<Task> TaskCollection::taskById(int id) const
+std::shared_ptr<Task> TaskCollection::taskById(int id) const
 {
-    const std::map<int, shared_ptr<Task> >::const_iterator it = d->m_tasks.find(id);
-    return it != d->m_tasks.end() ? it->second : shared_ptr<Task>();
+    const std::map<int, std::shared_ptr<Task> >::const_iterator it = d->m_tasks.find(id);
+    return it != d->m_tasks.end() ? it->second : std::shared_ptr<Task>();
 }
 
-std::vector<shared_ptr<Task> > TaskCollection::tasks() const
+std::vector<std::shared_ptr<Task> > TaskCollection::tasks() const
 {
-    typedef std::map<int, shared_ptr<Task> >::const_iterator ConstIterator;
-    std::vector<shared_ptr<Task> > res;
+    typedef std::map<int, std::shared_ptr<Task> >::const_iterator ConstIterator;
+    std::vector<std::shared_ptr<Task> > res;
     res.reserve(d->m_tasks.size());
     for (ConstIterator it = d->m_tasks.begin(), end = d->m_tasks.end(); it != end; ++it) {
         res.push_back(it->second);
@@ -187,15 +204,15 @@ std::vector<shared_ptr<Task> > TaskCollection::tasks() const
     return res;
 }
 
-void TaskCollection::setTasks(const std::vector<shared_ptr<Task> > &tasks)
+void TaskCollection::setTasks(const std::vector<std::shared_ptr<Task> > &tasks)
 {
-    Q_FOREACH (const shared_ptr<Task> &i, tasks) {
+    Q_FOREACH (const std::shared_ptr<Task> &i, tasks) {
         assert(i);
         d->m_tasks[i->id()] = i;
         connect(i.get(), SIGNAL(progress(QString,int,int)),
                 this, SLOT(taskProgress(QString,int,int)));
-        connect(i.get(), SIGNAL(result(boost::shared_ptr<const Kleo::Crypto::Task::Result>)),
-                this, SLOT(taskResult(boost::shared_ptr<const Kleo::Crypto::Task::Result>)));
+        connect(i.get(), SIGNAL(result(std::shared_ptr<const Kleo::Crypto::Task::Result>)),
+                this, SLOT(taskResult(std::shared_ptr<const Kleo::Crypto::Task::Result>)));
         connect(i.get(), SIGNAL(started()),
                 this, SLOT(taskStarted()));
     }
