@@ -43,13 +43,10 @@
 
 #include "ui_advancedsettingsdialog.h"
 
-#include <models/keycache.h>
-
 #include <commands/exportsecretkeycommand.h>
 #include <commands/exportopenpgpcertstoservercommand.h>
 #include <commands/exportcertificatecommand.h>
 
-#include <utils/formatting.h>
 #include <utils/validation.h>
 #include <utils/filedialog.h>
 #include "utils/gnupg-helper.h"
@@ -57,9 +54,11 @@
 #include <Libkleo/Stl_Util>
 #include <Libkleo/Dn>
 #include <Libkleo/OidMap>
-#include <Libkleo/KeyGenerationJob>
-#include <Libkleo/CryptoBackendFactory>
-#include <Libkleo/CryptoBackend>
+#include <Libkleo/KeyCache>
+#include <Libkleo/Formatting>
+
+#include <QGpgME/KeyGenerationJob>
+#include <QGpgME/Protocol>
 
 #include <gpgme++/global.h>
 #include <gpgme++/keygenerationresult.h>
@@ -80,9 +79,9 @@
 #include <QDesktopServices>
 #include <QUrlQuery>
 
-#include <boost/range.hpp>
-
 #include <algorithm>
+#include <cassert>
+
 #include <KSharedConfig>
 #include <QLocale>
 
@@ -90,7 +89,6 @@ using namespace Kleo;
 using namespace Kleo::NewCertificateUi;
 using namespace Kleo::Commands;
 using namespace GpgME;
-using namespace boost;
 
 static const char RSA_KEYSIZES_ENTRY[] = "RSAKeySizes";
 static const char DSA_KEYSIZES_ENTRY[] = "DSAKeySizes";
@@ -119,7 +117,7 @@ static const QStringList curveNames {
 
 static void set_tab_order(const QList<QWidget *> &wl)
 {
-    kdtools::for_each_adjacent_pair(wl, &QWidget::setTabOrder);
+    kdtools::for_each_adjacent_pair(wl.begin(), wl.end(), &QWidget::setTabOrder);
 }
 
 enum KeyAlgo { RSA, DSA, ELG, ECDSA, ECDH };
@@ -782,11 +780,11 @@ public:
 private:
     void startJob()
     {
-        const CryptoBackend::Protocol *const proto = CryptoBackendFactory::instance()->protocol(pgp() ? OpenPGP : CMS);
+        const auto proto = pgp() ? QGpgME::openpgp() : QGpgME::smime();
         if (!proto) {
             return;
         }
-        KeyGenerationJob *const j = proto->keyGenerationJob();
+        QGpgME::KeyGenerationJob *const j = proto->keyGenerationJob();
         if (!j) {
             return;
         }
@@ -841,7 +839,7 @@ private Q_SLOTS:
     }
 
 private:
-    QPointer<KeyGenerationJob> job;
+    QPointer<QGpgME::KeyGenerationJob> job;
     Ui_KeyCreationPage ui;
 };
 
@@ -1014,7 +1012,7 @@ private Q_SLOTS:
 #endif
     }
 
-    void invokeMailer(const QString &to, const QString &subject, QString body, const QString &attachment)
+    void invokeMailer(const QString &to, const QString &subject, const QString &body, const QString &attachment)
     {
         qCDebug(KLEOPATRA_LOG) << "to:" << to << "subject:" << subject
                                << "body:" << body << "attachment:" << attachment;
@@ -1431,7 +1429,8 @@ void EnterDetailsPage::updateForm()
 
     // create lineList in visual order, so requirementsAreMet()
     // complains from top to bottom:
-    lineList = kdtools::copy< QVector<Line> >(lines);
+    lineList.reserve(lines.count());
+    std::copy(lines.cbegin(), lines.cend(), std::back_inserter(lineList));
 
     widgets.push_back(ui.resultLE);
     widgets.push_back(ui.addEmailToDnCB);
@@ -1712,14 +1711,15 @@ QString KeyCreationPage::createGnupgKeyParms() const
     if (pgp() && expiryDate().isValid()) {
         s << "expire-date:   " << expiryDate().toString(Qt::ISODate) << endl;
     }
-    s     << "name-email:    " << encode_email(email())  << endl;
     if (pgp()) {
         s << "name-real:     " << name()                   << endl;
+        s << "name-email:    " << email()                  << endl;
         if (!comment().isEmpty()) {
             s << "name-comment:  " << comment()            << endl;
         }
     } else {
         s << "name-dn:       " << dn()                     << endl;
+        s << "name-email:    " << encode_email(email())    << endl;
         Q_FOREACH (const QString &email, additionalEMailAddresses()) {
             s << "name-email:    " << encode_email(email) << endl;
         }
